About us — Version 0.11.0.dev0

# About us

## History

### Development lead

The project started in August 2014 by Fernando Nogueira and focused on SMOTE implementation. Together with Guillaume Lemaitre, Dayvid Victor, and Christos Aridas, additional under-sampling and over-sampling methods have been implemented as well as major changes in the API to be fully compatible with scikit-learn.

## Contributors

Refers to GitHub contributors page.

## Citing imbalanced-learn

If you use imbalanced-learn in a scientific publication, we would appreciate citations to the following paper:

    @article{JMLR:v18:16-365,
    author  = {Guillaume  Lema{{\^i}}tre and Fernando Nogueira and Christos K. Aridas},
    title   = {Imbalanced-learn: A Python Toolbox to Tackle the Curse of Imbalanced Datasets in Machine Learning},
    journal = {Journal of Machine Learning Research},
    year    = {2017},
    volume  = {18},
    number  = {17},
    pages   = {1-5},
    url     = {http://jmlr.org/papers/v18/16-365.html}
    }

previous

Release history